@@ -38,14 +38,14 @@ panel.addWidget("org.kde.plasma.pager")
 
 var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
 var launcherlist = [ "preferred://browser",
-                     "applications:com.github.ovenwerks.studio-controls.desktop",
+                     "applications:patchance.desktop",
                      "applications:ardour.desktop",
                      "applications:com.obsproject.Studio.desktop",
                      "applications:org.kde.krita.desktop",
                      "applications:gimp.desktop",
                      "applications:org.kde.kdenlive.desktop",
                      "applications:org.kde.digikam.desktop",
-                     "applications:darktable.desktop",
+                     "applications:org.darktable.darktable.desktop",
                      "applications:systemsettings.desktop" ]
 taskmanager.writeConfig("launchers", launcherlist)
 
